@@ -12,6 +12,7 @@ from plone.supermodel import model
 from plone.supermodel.directives import primary
 from Products.CMFPlone.utils import safe_unicode
 from Products.Five import BrowserView
+from Products.validation import V_REQUIRED  # noqa
 from zope import schema
 from zope.interface import Invalid
 from zope.interface import invariant
@@ -85,4 +86,23 @@ class ProgramView(BrowserView):
 
 
 class FullprogramView(BrowserView):
-    pass
+
+    def track_list(self):
+        return api.content.find(depth=3, portal_type='collective.conferences.track')
+
+    def trackRoom(self, track):
+        path = track.getPath()
+        catalog = api.portal.get_tool('portal_catalog')
+        return catalog.getIndexDataForUID(path).get('trackroom')[0]
+
+    def track_talks_workshops(self, track):
+        tracktitle = track.Title
+        talks_workshops = api.content.find(depth=3,
+                                           portal_type=('collective.conferences.talk',
+                                                        'collective.conferences.workshop',
+                                                        'collective.conferences.conferencebreak'),
+                                           conferencetrack=tracktitle,
+                                           review_state='published',
+                                           sort_on='orderintrack')
+
+        return [z.getObject() for z in talks_workshops]
