@@ -24,6 +24,7 @@ from plone.supermodel import model
 from plone.supermodel.directives import primary
 from Products.CMFPlone.utils import safe_unicode
 from Products.Five import BrowserView
+from Products.validation import V_REQUIRED  # noqa
 from z3c.form import validator
 from z3c.form.browser.radio import RadioFieldWidget
 from z3c.relationfield.schema import RelationChoice
@@ -144,10 +145,10 @@ class ITalk(model.Schema):
         RadioFieldWidget,
     )
 
-    read_permission(talklength='cmf.ReviewPortalContent')
-    write_permission(talklength='cmf.ReviewPortalContent')
-    directives.widget(talklength=RadioFieldWidget)
-    talklength = schema.List(
+    read_permission(twclength='cmf.ReviewPortalContent')
+    write_permission(twclength='cmf.ReviewPortalContent')
+    directives.widget(twclength=RadioFieldWidget)
+    twclength = schema.List(
         title=_(safe_unicode('Talk Length')),
         description=_(safe_unicode('Set a time frame for the talk in minutes.')),
         value_type=schema.Choice(source='TalkLength'),
@@ -361,6 +362,34 @@ def newtalkadded(self, event):
             )
 
 
+def notifyAboutWorkflowChange(self, event):
+    state = api.content.get_state(self)
+    if api.portal.get_registry_record(
+            'plone.email_from_address') is not None:
+        contactaddress = api.portal.get_registry_record(
+            'plone.email_from_address')
+        current_user = api.user.get_current()
+        try:
+            api.portal.send_email(
+                recipient=current_user.getProperty('email'),
+                sender=contactaddress,
+                subject=(safe_unicode('Your Talk Proposal {0}')).format(self.title),
+                body=(safe_unicode(
+                    'The status of your proposed talk changed. '
+                    'The new status is {0}')).format(state),
+            )
+
+        except Exception:
+            api.portal.send_email(
+                recipient=contactaddress,
+                sender=contactaddress,
+                subject=(safe_unicode('Your Talk Proposal {0}')).format(self.title),
+                body=(safe_unicode(
+                    'The status of your proposed talk changed. '
+                    'The new status is {0}')).format(state),
+            )
+
+
 class ValidateTalkUniqueness(validator.SimpleFieldValidator):
     # Validate site-wide uniqueness of project titles.
 
@@ -411,3 +440,16 @@ class TalkView(BrowserView):
             if api.user.has_permission('View', obj=obj):
                 results.append(obj)
         return IContentListing(results)
+
+    def talkroom(self):
+        results = []
+        for rel in self.context.conferencetrack:
+            if rel.isBroken():
+                # skip broken relations
+                continue
+            obj = rel.to_object
+            if api.user.has_permission('View', obj=obj):
+                results.append(obj)
+            path = (str(results).strip(' []><Container at'))
+            catalog = api.portal.get_tool('portal_catalog')
+            return catalog.getIndexDataForUID(path).get('trackroom')[0]
