@@ -23,6 +23,7 @@ from plone.supermodel import model
 from plone.supermodel.directives import primary
 from Products.CMFPlone.utils import safe_unicode
 from Products.Five import BrowserView
+from Products.validation import V_REQUIRED  # noqa
 from z3c.form import validator
 from z3c.form.browser.radio import RadioFieldWidget
 from z3c.relationfield.schema import RelationChoice
@@ -338,6 +339,34 @@ def newtrainingadded(self, event):
             )
 
 
+def notifyAboutWorkflowChange(self, event):
+    state = api.content.get_state(self)
+    if api.portal.get_registry_record(
+            'plone.email_from_address') is not None:
+        contactaddress = api.portal.get_registry_record(
+            'plone.email_from_address')
+        current_user = api.user.get_current()
+        try:
+            api.portal.send_email(
+                recipient=current_user.getProperty('email'),
+                sender=contactaddress,
+                subject=(safe_unicode('Your Training Proposal {0}')).format(self.title),
+                body=(safe_unicode(
+                    'The status of your proposed training changed. '
+                    'The new status is {0}')).format(state),
+            )
+
+        except Exception:
+            api.portal.send_email(
+                recipient=contactaddress,
+                sender=contactaddress,
+                subject=(safe_unicode('Your Training Proposal {0}')).format(self.title),
+                body=(safe_unicode(
+                    'The status of your proposed training changed. '
+                    'The new status is {0}')).format(state),
+            )
+
+
 class ValidateTrainingUniqueness(validator.SimpleFieldValidator):
     # Validate site-wide uniqueness of training titles.
 
